"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.mapTests = exports.normalizePath = void 0;
/* c8 ignore next */
const node_path_1 = require("path");
const fs_js_1 = require("../polyfills/fs.js");
const list_files_js_1 = require("../modules/list-files.js");
const filter = /\.(js|cjs|mjs|ts|cts|mts)$/;
const normalizePath = (filePath) => filePath
    .replace(/(\.\/)/g, '')
    .replace(/^\.+/, '')
    .replace(/[/\\]+/g, node_path_1.sep)
    .replace(/\\/g, '/');
exports.normalizePath = normalizePath;
/* c8 ignore next */
const mapTests = (srcDir, testPaths) => __awaiter(void 0, void 0, void 0, function* () {
    const allTestFiles = [];
    const allSrcFiles = yield (0, list_files_js_1.listFiles)(srcDir, { filter });
    const importMap = new Map();
    for (const testPath of testPaths) {
        const stats = yield (0, fs_js_1.stat)(testPath);
        if (stats.isDirectory()) {
            const testFiles = yield (0, list_files_js_1.listFiles)(testPath, { filter });
            allTestFiles.push(...testFiles);
        }
        else if (stats.isFile() && filter.test(testPath))
            allTestFiles.push(testPath);
    }
    for (const testFile of allTestFiles) {
        const content = yield (0, fs_js_1.readFile)(testFile, 'utf-8');
        for (const srcFile of allSrcFiles) {
            const relativePath = (0, exports.normalizePath)((0, node_path_1.relative)((0, node_path_1.dirname)(testFile), srcFile));
            const normalizedSrcFile = (0, exports.normalizePath)(srcFile);
            /* c8 ignore start */
            if (content.includes(relativePath.replace(filter, '')) ||
                content.includes(normalizedSrcFile)) {
                if (!importMap.has(normalizedSrcFile))
                    importMap.set(normalizedSrcFile, []);
                importMap.get(normalizedSrcFile).push((0, exports.normalizePath)(testFile));
            }
            /* c8 ignore stop */
        }
    }
    return importMap;
});
exports.mapTests = mapTests;
